pub struct DeleteMany<E: EntityTrait> { /* private fields */ }Expand description
A DELETE over any number of rows of an entity.
Implementations
Sourceimpl<E: EntityTrait> DeleteMany<E>
impl<E: EntityTrait> DeleteMany<E>
Sourcepub fn filter(self, cond: impl IntoCondition) -> Self
pub fn filter(self, cond: impl IntoCondition) -> Self
Adds a WHERE condition, ANDed with the previous ones.
Sourcepub async fn exec<C: ConnectionTrait>(self, db: &C) -> Result<DeleteResult>
pub async fn exec<C: ConnectionTrait>(self, db: &C) -> Result<DeleteResult>
Sourcepub async fn exec_with_returning<C: ConnectionTrait>(
self,
db: &C,
) -> Result<Vec<E::Model>>
pub async fn exec_with_returning<C: ConnectionTrait>( self, db: &C, ) -> Result<Vec<E::Model>>
Executes the delete with RETURNING * and decodes the removed rows.
Errors
Returns DbErr::Driver when the statement fails or a returned row
cannot be decoded.