pub struct DeleteOne<A: ActiveModelTrait> { /* private fields */ }Expand description
A DELETE of one active model, matched by primary key.
Implementations
Sourceimpl<A: ActiveModelTrait> DeleteOne<A>
impl<A: ActiveModelTrait> DeleteOne<A>
Sourcepub async fn exec<C: ConnectionTrait>(self, db: &C) -> Result<DeleteResult>
pub async fn exec<C: ConnectionTrait>(self, db: &C) -> Result<DeleteResult>
Executes the delete.
Errors
Returns DbErr::PrimaryKeyNotSet when a key attribute of the model
is NotSet; DbErr::Driver when the statement fails.
Sourcepub async fn exec_with_returning<C: ConnectionTrait>(
self,
db: &C,
) -> Result<<A::Entity as EntityTrait>::Model>
pub async fn exec_with_returning<C: ConnectionTrait>( self, db: &C, ) -> Result<<A::Entity as EntityTrait>::Model>
Executes the delete with RETURNING * and returns the removed row.
Errors
Returns DbErr::PrimaryKeyNotSet when a key attribute of the model
is NotSet; DbErr::RecordNotFound when no row matched;
DbErr::Driver when the statement fails or the returned row cannot
be decoded.