pub struct Func {
pub name: &'static str,
pub args: Vec<Expr>,
pub distinct: bool,
}Expand description
A function call.
Fields
name: &'static strThe function name, written verbatim.
args: Vec<Expr>The arguments.
distinct: boolWhether DISTINCT applies to the first argument, as in aggregates.
Implementations
Sourceimpl Func
impl Func
Sourcepub fn call(name: &'static str, args: impl IntoIterator<Item = Expr>) -> Expr
pub fn call(name: &'static str, args: impl IntoIterator<Item = Expr>) -> Expr
Builds a call to any function.
The name is written verbatim, so this is the escape hatch for engine functions that have no dedicated constructor.
Sourcepub fn count_star() -> Expr
pub fn count_star() -> Expr
Builds COUNT(*).
Sourcepub fn count_distinct(expr: Expr) -> Expr
pub fn count_distinct(expr: Expr) -> Expr
Builds COUNT(DISTINCT expr).
Sourcepub fn coalesce(args: impl IntoIterator<Item = Expr>) -> Expr
pub fn coalesce(args: impl IntoIterator<Item = Expr>) -> Expr
Builds COALESCE(a, b, ...).
Sourcepub fn json_extract(json: Expr, path: impl Into<Value>) -> Expr
pub fn json_extract(json: Expr, path: impl Into<Value>) -> Expr
Builds json_extract(json, path), binding path as a parameter.
Sourcepub fn vector_distance_cos(a: Expr, b: Expr) -> Expr
pub fn vector_distance_cos(a: Expr, b: Expr) -> Expr
Builds vector_distance_cos(a, b) — Turso vector search.
Sourcepub fn vector_distance_l2(a: Expr, b: Expr) -> Expr
pub fn vector_distance_l2(a: Expr, b: Expr) -> Expr
Builds vector_distance_l2(a, b) — Turso vector search.